# Changelog 

## Unreleased 

* [new] Export to hdf5 by io3d
* [new] Patient info in load screen by io3d
* [new] Script for color visualization in ParaView
* [new] Automatic lisa processing for multiple files
* [new] Body navigation structures

* [new] Save seeds for later use
* [new] Turn convex area into seeds
* [new] Dialog before delete all seeds 
* [new] Label vessel tree
* [new] Split tissue based on labeled vessel tree
* [new] Simple GUI for select from list
* [new] Select label dialog (require less space)
* [improvement] More descriptive status messages
* [improvement] Split tissue split tissue near to missed branche between selected branches
* [improvement] Relabel multiple labels to one label
* [fix] Read/write DICOM overlay
* [fix] Cancel label selection
* [Added] Export and import seeds

## 1.9.51 2018-07-21

* Resize data from GUI
* New version of automatic threshold for vessel segmentation
* Turn on debug mode from menu

## 1.9.50

* Remove wget and pywget dependency
* Python 3 compatibility
* Mask segmentation added
* Fix a lot automatic tests


## 1.9.47

* Convex shapes in manual segmentation
* Smoothing in GUI

## 1.9.46

* More general vessel function

## 1.9.45

* Mask segmentation added

## < 1.9.44

* New Save dialog
* Save 1D model
* Connected Threshod Segmentation is not dependent on prev organ segmentation



## 2014-07-23 v1.3
Histology Analyser added. It is dependent on skelet3d module.
In stable version is lession button dissabled.

## 2014-04-09
Input data path start is in ~/lisa_data and can be defined in config.
New button "Open file" can import .pklz or .raw data
Vessel Segmentation for segmentation of vessels
Middle pen selected on start of automatic segmentation



2014-01-21
Window/Level in crop window
Time measurement - start is after data load
Mask deletion
GUI


2013-10-07 zipped pkl files

